Lexipol - Home
Description: Lexipol is America's leading provider of state-specific policies and verifiable policy training for public safety organizations

- # Law Enforcement

  Freeing your people to focus on serving and protecting the community

  Learn More

- # Fire

  Empowering you to focus on managing and improving your agency

  Learn More

- # Custody

  Saving you money with reduced claims and legal costs

  Learn More

# Lexipol is America’s leading provider of risk management policies and resources for organizations, delivering our services through a unique, web-based development system. Lexipol offers state-specific policy manuals that are integrated with scenario-based daily training on high-risk, low-frequency events.

- Custom Policy Content
- Daily Training Bulletins
- Implementation Services
- User-Friendly Software

- Lexipol provides more than 150 policies based on federal and state statutes, case law, regulations and best practices.
- The Lexipol policy manual is written by legal and public safety professionals who constantly monitor major court decisions, legislation and emerging trends affecting your industry. Lexipol provides regular updates in response to legislative mandates, case law and the evolution of best practices.

- Lexipol Daily Training Bulletins bring the manual into practice through real-life, scenario-based training exercises emphasizing high-risk, low frequency events. Completed and verified in less than ten minutes per day, Daily Training Bulletins often qualify for continuous training certification.
- Each month, Lexipol provides customizable, scenario-based training bulletins that link directly to your policy manual. Agencies can customize the Daily Training Bulletins to address agency-specific topics.

- Lexipol’s experienced team can assist with implementation of your Lexipol manual, freeing your personnel to focus on serving and protecting the community. Lexipol’s team can also manage the administration of critical updates and your agency’s Daily Training Bulletins.
- Lexipol’s Implementation and Management Services allow your agency to control policy while we do all the work.

- Lexipol’s Policy Manual and Daily Training Bulletin service is accessed through our Knowledge Management System (KMS). KMS is a web-based solution, instantly available 24/7 on all internet devices.
- Our KMS system provides a robust web-based tool set, allowing you to manage and edit your agency’s content and provides your personnel easy access to your department’s Policy Manual and Daily Training Bulletins.

### How Exposed Are You?

Take our 10 question defensible policy survey to see your Lexipol Total Compliance Score.

Begin Survey ›
Request Live Demo
See first-hand how Lexipol can help your organization

## Sign-up To Receive Today's Tip

- Title*
- First Name*
- Last Name*
- Organization Name*
- Email*
- Phone Number*
- State*

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]

## Download Presentation

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]

## Request Live Demo

- Name*
- Title*
- Email*
- Phone*
- Organization*
- State*
- Service Line*
  - Law Enforcement
  - Fire
  - Custody

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]

## Contact Us

Lexipol, LLC
6B Liberty, Suite 200
Aliso Viejo, CA 92656
T: 949.484.4444
F: 949.484.4443

Please use the form below for specific questions. A member of our team will contact you:

- Name*
- Title*
- Organization Name*
- Organization Type*
- Phone*
- Email*
- State*
- About your Request*
  - I would like to learn more about subscribing to the Lexipol Policy Manual and DTBs
  - I have a password or technical question about the Lexipol Knowledge Management System
  - I have a question about my policy content
  - I have a question about my statement or invoice
  - Other
- Comments

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]